@@ -39,7 +39,7 @@ TransfersView::TransfersView(QWidget * parent)
     header()->setDefaultAlignment(Qt::AlignCenter);
     header()->setMinimumSectionSize(80);    
     header()->setContextMenuPolicy(Qt::CustomContextMenu);
-    header()->setClickable(true);
+    header()->setSectionsClickable(true);
     m_headerMenu = new QMenu(header());
 
     setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -76,7 +76,7 @@ void TransfersView::setModel(QAbstractItemModel * model)
         openPersistentEditor(model->index(i, TransferTreeModel::Status, QModelIndex()));
     }
 
-    QByteArray loadedState = QByteArray::fromBase64(Settings::headerState().toAscii());
+    QByteArray loadedState = QByteArray::fromBase64(Settings::headerState().toLatin1());
     if (loadedState.isEmpty()) {
         setColumnWidth(0 , 230);
     } else {
